package yangtz.cs.liu.campus.service.impl.schoolStudio;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import yangtz.cs.liu.campus.domain.schoolStudio.SchoolStudioUse;
import yangtz.cs.liu.campus.mapper.schoolStudio.SchoolStudioUseMapper;
import yangtz.cs.liu.campus.service.schoolStudio.ISchoolStudioUseService;

import java.util.List;

/**
 * 录播室使用情况Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-10
 */
@Service
public class SchoolStudioUseServiceImpl implements ISchoolStudioUseService
{
    @Autowired
    private SchoolStudioUseMapper schoolStudioUseMapper;

    /**
     * 录播室使用情况统计
     * @param schoolStudioUse
     * @return
     */
    @Override
    public List<SchoolStudioUse> selectStudioUse(SchoolStudioUse schoolStudioUse) {
        return schoolStudioUseMapper.selectStudioUse(schoolStudioUse);
    }















//    /**
//     * 查询录播室使用情况
//     *
//     * @param id 录播室使用情况主键
//     * @return 录播室使用情况
//     */
//    @Override
//    public SchoolStudioUse selectSchoolStudioUseById(Long id)
//    {
//        return schoolStudioUseMapper.selectSchoolStudioUseById(id);
//    }
//
//    /**
//     * 查询录播室使用情况列表
//     *
//     * @param schoolStudioUse 录播室使用情况
//     * @return 录播室使用情况
//     */
//    @Override
//    public List<SchoolStudioUse> selectSchoolStudioUseList(SchoolStudioUse schoolStudioUse)
//    {
//        return schoolStudioUseMapper.selectSchoolStudioUseList(schoolStudioUse);
//    }
//
//    /**
//     * 新增录播室使用情况
//     *
//     * @param schoolStudioUse 录播室使用情况
//     * @return 结果
//     */
//    @Override
//    public int insertSchoolStudioUse(SchoolStudioUse schoolStudioUse)
//    {
//        return schoolStudioUseMapper.insertSchoolStudioUse(schoolStudioUse);
//    }
//
//    /**
//     * 修改录播室使用情况
//     *
//     * @param schoolStudioUse 录播室使用情况
//     * @return 结果
//     */
//    @Override
//    public int updateSchoolStudioUse(SchoolStudioUse schoolStudioUse)
//    {
//        return schoolStudioUseMapper.updateSchoolStudioUse(schoolStudioUse);
//    }
//
//    /**
//     * 批量删除录播室使用情况
//     *
//     * @param ids 需要删除的录播室使用情况主键
//     * @return 结果
//     */
//    @Override
//    public int deleteSchoolStudioUseByIds(Long[] ids)
//    {
//        return schoolStudioUseMapper.deleteSchoolStudioUseByIds(ids);
//    }
//
//    /**
//     * 删除录播室使用情况信息
//     *
//     * @param id 录播室使用情况主键
//     * @return 结果
//     */
//    @Override
//    public int deleteSchoolStudioUseById(Long id)
//    {
//        return schoolStudioUseMapper.deleteSchoolStudioUseById(id);
//    }
}
